@@ -1,33 +1,18 @@
 /*
-    Copyright (c) 2007 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2007 Volker Krause <vkrause@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include "test_utils.h"
-
-#include <control.h>
-#include <collection.h>
-#include <collectionfetchjob.h>
-#include <collectionfetchscope.h>
-#include <subscriptionjob_p.h>
+#include "control.h"
+#include "collection.h"
+#include "collectionfetchjob.h"
+#include "collectionfetchscope.h"
+#include "subscriptionjob_p.h"
+#include "qtest_akonadi.h"
 
 #include <QObject>
 
-#include <qtest_akonadi.h>
 
 using namespace Akonadi;
 
@@ -44,13 +29,13 @@ private Q_SLOTS:
     void testSubscribe()
     {
         Collection::List l;
-        l << Collection(collectionIdFromPath(QStringLiteral("res2/foo2")));
+        l << Collection(AkonadiTest::collectionIdFromPath(QStringLiteral("res2/foo2")));
         QVERIFY(l.first().isValid());
         SubscriptionJob *sjob = new SubscriptionJob(this);
         sjob->unsubscribe(l);
         AKVERIFYEXEC(sjob);
 
-        const Collection res2Col = Collection(collectionIdFromPath(QStringLiteral("res2")));
+        const Collection res2Col = Collection(AkonadiTest::collectionIdFromPath(QStringLiteral("res2")));
         QVERIFY(res2Col.isValid());
         CollectionFetchJob *ljob = new CollectionFetchJob(res2Col, CollectionFetchJob::FirstLevel, this);
         AKVERIFYEXEC(ljob);
