@@ -5,7 +5,6 @@
 */
 
 #include "preprocessorbase_p.h"
-#include "preprocessorbase.h"
 
 #include <QDBusConnection>
 #include "preprocessoradaptor.h"
@@ -18,8 +17,6 @@ using namespace Akonadi;
 
 PreprocessorBasePrivate::PreprocessorBasePrivate(PreprocessorBase *parent)
     : AgentBasePrivate(parent)
-    , mInDelayedProcessing(false)
-    , mDelayedProcessingItemId(0)
 {
     Q_Q(PreprocessorBase);
 
