@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2006 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2006 Volker Krause <vkrause@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "collectioncreatejob.h"
@@ -29,7 +16,7 @@ using namespace Akonadi;
 class Akonadi::CollectionCreateJobPrivate : public JobPrivate
 {
 public:
-    CollectionCreateJobPrivate(CollectionCreateJob *parent)
+    explicit CollectionCreateJobPrivate(CollectionCreateJob *parent)
         : JobPrivate(parent)
     {
     }
@@ -105,7 +92,7 @@ bool CollectionCreateJob::doHandleResponse(qint64 tag, const Protocol::CommandPt
     }
 
     if (response->type() == Protocol::Command::FetchCollections) {
-        auto &resp = Protocol::cmdCast<Protocol::FetchCollectionsResponse>(response);
+        const auto &resp = Protocol::cmdCast<Protocol::FetchCollectionsResponse>(response);
         Collection col = ProtocolHelper::parseCollection(resp);
         if (!col.isValid()) {
             setError(Unknown);
