@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2006 - 2007 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2006-2007 Volker Krause <vkrause@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -26,10 +26,6 @@ using namespace Akonadi;
 
 ItemModifyJobPrivate::ItemModifyJobPrivate(ItemModifyJob *parent)
     : JobPrivate(parent)
-    , mRevCheck(true)
-    , mIgnorePayload(false)
-    , mAutomaticConflictHandlingEnabled(true)
-    , mSilent(false)
 {
 }
 
