@@ -1,21 +1,8 @@
 /*
- *  Copyright (c) 2015 Daniel Vrátil <dvratil@redhat.com>
- *  Copyright (c) 2016 Daniel Vrátil <dvratil@kde.org>
+ *  SPDX-FileCopyrightText: 2015 Daniel Vrátil <dvratil@redhat.com>
+ *  SPDX-FileCopyrightText: 2016 Daniel Vrátil <dvratil@kde.org>
  *
- *  This library is free software; you can redistribute it and/or modify it
- *  under the terms of the GNU Library General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or (at your
- *  option) any later version.
- *
- *  This library is distributed in the hope that it will be useful, but WITHOUT
- *  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- *  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
- *  License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to the
- *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- *  02110-1301, USA.
+ *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "protocol_p.h"
@@ -32,6 +19,8 @@
 
 #include <cassert>
 
+// clazy:excludeall=function-args-by-value
+
 #undef AKONADI_DECLARE_PRIVATE
 #define AKONADI_DECLARE_PRIVATE(Class) \
 inline Class##Private* Class::d_func() {\
@@ -42,7 +31,7 @@ inline const Class##Private* Class::d_func() const {\
 }
 
 #define COMPARE(prop) \
-    (prop == ((decltype(this)) other)->prop)
+    ((prop) == ((decltype(this)) other)->prop)
 
 namespace Akonadi {
 namespace Protocol {
@@ -153,7 +142,7 @@ QDebug operator<<(QDebug _dbg, Command::Type type)
 template<typename T>
 DataStream &operator<<(DataStream &stream, const QSharedPointer<T> &ptr)
 {
-    Protocol::serialize(stream.device(), ptr);
+    Protocol::serialize(stream, ptr);
     return stream;
 }
 
@@ -476,7 +465,7 @@ private:
     }
 };
 
-Q_GLOBAL_STATIC(FactoryPrivate, sFactoryPrivate)
+Q_GLOBAL_STATIC(FactoryPrivate, sFactoryPrivate) // NOLINT(readability-redundant-member-init)
 
 CommandPtr Factory::command(Command::Type type)
 {
@@ -908,8 +897,8 @@ inline bool containerComparator(const Container<QSharedPointer<T>> &c1,
     return true;
 }
 
-}
-}
+} // namespace Protocol
+} // namespace Akonadi
 
 /******************************************************************************/
 
