@@ -25,7 +25,6 @@
 #include <unistd.h>
 #endif
 #include <chrono>
-#include <optional>
 
 using namespace std::chrono_literals;
 
@@ -123,7 +122,7 @@ QStringList DbConfigPostgresql::postgresSearchPaths(const QString &versionedPath
     return paths;
 }
 
-bool DbConfigPostgresql::init(QSettings &settings)
+bool DbConfigPostgresql::init(QSettings &settings, bool storeSettings)
 {
     // determine default settings depending on the driver
     QString defaultHostName;
@@ -186,19 +185,44 @@ bool DbConfigPostgresql::init(QSettings &settings)
     }
     settings.endGroup();
 
-    // store back the default values
-    settings.beginGroup(driverName());
-    settings.setValue(QStringLiteral("Name"), mDatabaseName);
-    settings.setValue(QStringLiteral("Host"), mHostName);
-    if (mHostPort) {
-        settings.setValue(QStringLiteral("Port"), mHostPort);
+    if (storeSettings) {
+        // store back the default values
+        settings.beginGroup(driverName());
+        settings.setValue(QStringLiteral("Name"), mDatabaseName);
+        settings.setValue(QStringLiteral("Host"), mHostName);
+        if (mHostPort) {
+            settings.setValue(QStringLiteral("Port"), mHostPort);
+        }
+        settings.setValue(QStringLiteral("Options"), mConnectionOptions);
+        settings.setValue(QStringLiteral("ServerPath"), mServerPath);
+        settings.setValue(QStringLiteral("InitDbPath"), mInitDbPath);
+        settings.setValue(QStringLiteral("StartServer"), mInternalServer);
+        settings.endGroup();
+        settings.sync();
+    }
+
+    return true;
+}
+
+bool DbConfigPostgresql::isAvailable(QSettings &settings)
+{
+    if (!QSqlDatabase::drivers().contains(driverName())) {
+        return false;
+    }
+
+    if (!init(settings, false)) {
+        return false;
+    }
+
+    if (mInternalServer) {
+        if (mInitDbPath.isEmpty() || !QFile::exists(mInitDbPath)) {
+            return false;
+        }
+
+        if (mServerPath.isEmpty() || !QFile::exists(mServerPath)) {
+            return false;
+        }
     }
-    settings.setValue(QStringLiteral("Options"), mConnectionOptions);
-    settings.setValue(QStringLiteral("ServerPath"), mServerPath);
-    settings.setValue(QStringLiteral("InitDbPath"), mInitDbPath);
-    settings.setValue(QStringLiteral("StartServer"), mInternalServer);
-    settings.endGroup();
-    settings.sync();
 
     return true;
 }
