@@ -19,7 +19,6 @@
 #include "entitytreemodel.h"
 #include "favoritecollectionsmodel.h"
 #include "itemdeletejob.h"
-#include "metatypes.h"
 #include "pastehelper_p.h"
 #include "specialcollectionattribute.h"
 #include "collectionpropertiesdialog.h"
@@ -46,6 +45,8 @@
 #include <QItemSelectionModel>
 #include <QPointer>
 #include <QInputDialog>
+#include <QRegularExpression>
+#include <QTimer>
 
 using namespace Akonadi;
 
@@ -271,6 +272,9 @@ public:
         setContextText(StandardActionManager::Paste, StandardActionManager::ErrorMessageTitle,
                        i18n("Paste failed"));
 
+        mDelayedUpdateTimer.setSingleShot(true);
+        connect(&mDelayedUpdateTimer, &QTimer::timeout, q, [this]() { updateActions(); });
+
         qRegisterMetaType<Akonadi::Item::List>("Akonadi::Item::List");
     }
 
@@ -460,6 +464,12 @@ public:
         return collectionList;
     }
 
+    void delayedUpdateActions()
+    {
+        // Compress changes (e.g. when deleting many rows, do this only once)
+        mDelayedUpdateTimer.start(0);
+    }
+
     void updateActions()
     {
         // favorite collections
@@ -497,6 +507,7 @@ public:
         if (favoritesModel) {
             enableAction(StandardActionManager::SynchronizeFavoriteCollections, (favoritesModel->rowCount() > 0));
         }
+        Q_EMIT q->selectionsChanged(selectedCollectionsList, selectedFavoriteCollectionsList, selectedItems);
         Q_EMIT q->actionStateUpdated();
     }
 
@@ -1537,7 +1548,7 @@ public:
         }
 
         const QString str = text.subs(count).toString();
-        const int argCount = str.count(QRegExp(QStringLiteral("%[0-9]")));
+        const int argCount = str.count(QRegularExpression(QStringLiteral("%[0-9]")));
         if (argCount > 0) {
             return text.subs(count).subs(value).toString();
         } else {
@@ -1545,7 +1556,7 @@ public:
         }
     }
 
-    StandardActionManager *q;
+    StandardActionManager *const q;
     KActionCollection *actionCollection;
     QWidget *parentWidget;
     QItemSelectionModel *collectionSelectionModel;
@@ -1556,6 +1567,7 @@ public:
     QVector<QAction *> actions;
     QHash<StandardActionManager::Type, KLocalizedString> pluralLabels;
     QHash<StandardActionManager::Type, KLocalizedString> pluralIconLabels;
+    QTimer mDelayedUpdateTimer;
 
     struct ContextTextEntry {
         QString text;
@@ -1604,7 +1616,7 @@ void StandardActionManager::setCollectionSelectionModel(QItemSelectionModel *sel
 void StandardActionManager::setItemSelectionModel(QItemSelectionModel *selectionModel)
 {
     d->itemSelectionModel = selectionModel;
-    connect(selectionModel, &QItemSelectionModel::selectionChanged, this, [this]() { d->updateActions(); });
+    connect(selectionModel, &QItemSelectionModel::selectionChanged, this, [this]() { d->delayedUpdateActions(); });
 }
 
 void StandardActionManager::setFavoriteCollectionsModel(FavoriteCollectionsModel *favoritesModel)
